#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 28-02-2007
# source location  : http://www.epm.ornl.gov/pvm/pvm_home.html
# url              : http://www.netlib.org/pvm3/pvm3.4.5.tgz
# based on         : http://www.xslack.zsh.bash.org.pl/packages/dozzie/pvm/pvm.SlackBuild
# patches "stolen" from gentoo: http://sources.gentoo.org/viewcvs.py/gentoo-x86/sys-cluster/pvm/files/

NAME=pvm
VERSION=3.4.5
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tgz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf ${NAME}3
  if [ -f $NAME$VERSION.$EXTENSION ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$NAME$VERSION.$EXTENSION ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$NAME$VERSION.$EXTENSION $TMP/
	  echo "done"
  else
          wget -c http://www.netlib.org/pvm3/${NAME}${VERSION}.$EXTENSION
  fi
  tar xf $NAME$VERSION.$EXTENSION

cd ${NAME}3

# Build and install:
PVM_ARCH=`./lib/pvmgetarch`
export PVM_ROOT=$TMP/${NAME}3

perl -pi -e 's{[/\w.-]*/rsh}{/usr/bin/ssh}' conf/$PVM_ARCH.def
patch -p1 --verbose < $CWD/dynamic-libs.patch
patch -p1 --verbose < $CWD/pvm-3.4.5-strerror.patch
patch -p1 --verbose < $CWD/pvm-3.4.5-bug_147337.patch
patch -p1 --verbose < $CWD/pvm-3.4.5-envvars.patch
patch -p1 --verbose < $CWD/pvm-3.4.5-extra-arches.patch
patch -p1 --verbose < $CWD/pvm-3.4.5-gcc-4.1.patch

#./lib/aimk -here -f ./conf/`./lib/pvmtmparch`.def -f ./Makefile.aimk PVMDIR=`pwd` CFLOPTS='-g -O2 -DSAFETMP -DPVMDPATH=\"pvmd\" -DPVMDFILE=\"/usr/bin/pvmd\" -DPVM_DEFAULT_ROOT=\"/usr/lib/pvm3\" -DOVERLOADHOST' default 
make || exit 1

mkdir -p $PKG/usr/bin $PKG/usr/include $PKG/usr/lib/pvm3/lib $PKG/usr/lib/pvm3/conf

cp bin/${PVM_ARCH}/pvmgs $PKG/usr/bin
cp lib/pvmgetarch $PKG/usr/bin
cp lib/${PVM_ARCH}/pvm $PKG/usr/bin
cp lib/${PVM_ARCH}/pvmgs $PKG/usr/bin
cp lib/${PVM_ARCH}/pvmd3 $PKG/usr/bin/pvmd
ln -sf ../../../bin/pvmgetarch $PKG/usr/lib/pvm3/lib/pvmgetarch
ln -sf ../../../bin/pvm $PKG/usr/lib/pvm3/lib/pvm
ln -sf ../../../bin/pvmgs $PKG/usr/lib/pvm3/lib/pvmgs
ln -sf ../../../bin/pvmd $PKG/usr/lib/pvm3/lib/pvmd

cp lib/aimk $PKG/usr/bin
cp bin/${PVM_ARCH}/{pvm_gstat,pvmgroups,tracer,trcsort} $PKG/usr/bin
cp lib/${PVM_ARCH}/*.a $PKG/usr/lib
cp conf/${PVM_ARCH}.{def,m4} $PKG/usr/lib/pvm3/conf
cp include/* $PKG/usr/include
ln -sf libpvm3.so.${VERSION} $PKG/usr/lib/libpvm3.so
ln -sf libgpvm3.so.${VERSION} $PKG/usr/lib/libgpvm3.so

cp lib/${PVM_ARCH}/libpvm3.so $PKG/usr/lib/libpvm3.so.${VERSION}
cp lib/${PVM_ARCH}/libgpvm3.so $PKG/usr/lib/libgpvm3.so.${VERSION}
ln -s libpvm3.so.${VERSION} $PKG/usr/lib/libpvm3.so.${VERSION_MAJOR}
ln -s libgpvm3.so.${VERSION} $PKG/usr/lib/libgpvm3.so.${VERSION_MAJOR}
mkdir -p $PKG/usr/man
cp -r man/man1 $PKG/usr/man
cp -r man/man3 $PKG/usr/man

mkdir -p $PKG/etc/profile.d/
cat <<"EOF" > $PKG/etc/profile.d/pvm.csh 
#!/bin/csh

setenv PVM_ROOT /usr/lib/pvm3
setenv PATH ${PATH}:${HOME}/pvm3/bin/LINUX
EOF

cat <<"EOF" > $PKG/etc/profile.d/pvm.sh
#!/bin/sh
export PVM_ROOT=/usr/lib/pvm3
export PATH=$PATH:$HOME/pvm3/bin/LINUX
EOF

chmod a+x $PKG/etc/profile.d/pvm.*

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
cd $PKG/usr/man
for i in $(ls man1/*.1);do
	sed -e '/.\" $Id: /d' < $i > $i.new
	rm -f $i
	mv $i.new $i
done
for i in $(ls man3/*.3);do
	sed -e '/.\" $Id: /d' < $i > $i.new
	rm -f $i
	mv $i.new $i
done
# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
	find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
	find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi


# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="Readme Readme.mp doc/*"
cd $TMP/${NAME}3
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

# 
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
cp -a $CWD/dynamic-libs.patch $PKG/usr/src/$NAME-$VERSION/
cp -a $CWD/pvm-3.4.5-strerror.patch $PKG/usr/src/$NAME-$VERSION/
cp -a $CWD/pvm-3.4.5-bug_147337.patch $PKG/usr/src/$NAME-$VERSION/
cp -a $CWD/pvm-3.4.5-envvars.patch $PKG/usr/src/$NAME-$VERSION/
cp -a $CWD/pvm-3.4.5-extra-arches.patch $PKG/usr/src/$NAME-$VERSION/
cp -a $CWD/pvm-3.4.5-gcc-4.1.patch $PKG/usr/src/$NAME-$VERSION/

mkdir -p $PKG/install

echo "$NAME: $NAME (Parallel Virtual Machine)
$NAME:
$NAME: PVM (Parallel Virtual Machine) is a software package that permits a
$NAME: heterogeneous collection of Unix and/or Windows computers hooked
$NAME: together by a network to be used as a single large parallel computer.
$NAME: Thus large computational problems can be solved more cost effectively
$NAME: by using the aggregate power and memory of many computers. 
$NAME: 
$NAME: 
$NAME: 
$NAME:" > $PKG/install/slack-desc


#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
echo "" > $NAME-$VERSION-$ARCH-$BUILD.dep

